powered by
Given results for rgenie grep or deletion analysis of a set of regions, merges together tables across regions.
bind_results(results)
A list of rgenie results from either grep or deletion analyses.
Returns a list containing the same tables as in an individual result, but concatenated across regions.
grep_analysis
deletion_analysis
# NOT RUN { # Note: First run deletion_analysis() # mul1_del_results is a pre-loaded result del_tables = bind_results(mul1_del_results) # }
Run the code above in your browser using DataLab