Learn R Programming

rgenie (version 1.0.0)

deletion_plots: Returns all main plots for a single deletion analysis result.

Description

Returns all main plots for a single deletion analysis result.

Usage

deletion_plots(
  del_result,
  opts = genie_plot_options(),
  variance_components_plot = FALSE,
  power_plots = FALSE
)

Arguments

del_result

Result from a call to deletion_analysis.

opts

A list with all options needed for rgenie plotting functions.

variance_components_plot

If TRUE, then variance_components_plot() is called.

power_plots

If TRUE, then power_plots() is called.

Value

Returns a list of ggplot objects.

See Also

genie_plot_options

deletion_analysis

deletion_summary_plot

deletion_alleles_plot

deletion_profile_plot

replicate_summary_plot

replicate_qc_plot

allele_effect_plot

variance_components_plot

power_plots

Examples

Run this code
# NOT RUN {
# Note: First run deletion_analysis()
# mul1_del_results is a pre-loaded result

deletion_plots(mul1_del_results[[1]], genie_plot_options())
# }

Run the code above in your browser using DataLab