Learn R Programming

rgenie (version 1.0.0)

download_example: Downloads example data for rgenie.

Description

The example data is a set of BAM files for GenIE replicates.

Usage

download_example(dir, name = "MUL1", overwrite = FALSE, quiet = FALSE)

Arguments

dir

Directory where example data should be put.

name

The name of the example to download.

overwrite

If FALSE, then data are not downloaded if directory 'dir/name' already exists. Otherwise, all data are downloaded (possibly overwriting files).

quiet

If TRUE, then no messages are printing during the analysis.

Value

Returns a list containing the same tables as in an individual result, but concatenated across regions.

See Also

grep_analysis

deletion_analysis

Examples

Run this code
# NOT RUN {
download_example(dir = "~/genie_example", name = "MUL1")
# Data are downloaded and we can run an rgenie analysis
setwd("~/genie_example/MUL1/")
regions = readr::read_tsv("mul1.genie_regions.tsv")
replicates = readr::read_tsv("mul1.genie_replicates.tsv")
grep_results = grep_analysis(regions, replicates)
# }

Run the code above in your browser using DataLab