Learn R Programming

rgenie (version 1.0.0)

power_analysis: Performs estimates of power to detect effects of alleles at different read fractions, given the variance observed in the del_result replicates.

Description

Performs estimates of power to detect effects of alleles at different read fractions, given the variance observed in the del_result replicates.

Usage

power_analysis(del_result, allele_min_reads = 100, WT_fraction = NA)

Arguments

del_result

The result from deletion_analysis

allele_min_reads

The minimum number of reads that a deletion allele must have across all replicates to be included.

WT_fraction

If specified, then the model will assume this fraction of WT reads

Value

Returns...

See Also

deletion_analysis

power_plots

Examples

Run this code
# NOT RUN {
# Note: First run deletion_analysis()
# mul1_del_results is a pre-loaded result

pwr = power_analysis(mul1_del_results[[1]])
power_plots(mul1_del_results[[1]])
# }

Run the code above in your browser using DataLab