Learn R Programming

rgenie (version 1.0.0)

power_plots: Returns a set of plots summarising the expected power to detect a significant effect given various allele fraction and effect size combinations.

Description

Returns a set of plots summarising the expected power to detect a significant effect given various allele fraction and effect size combinations.

Usage

power_plots(del_result, allele_min_reads = 100, WT_fraction = NA)

Arguments

del_result

Result from a call to deletion_analysis.

allele_min_reads

The minimum number of reads that a deletion allele must have across all replicates to be included.

WT_fraction

If specified, then the model will assume this fraction of WT reads

Value

Returns a list with three ggplot objects:

  • cv_plot

  • power_plot

  • replicate_allocation_plot

See Also

deletion_analysis

Examples

Run this code
# NOT RUN {
# Note: First run deletion_analysis()
# mul1_del_results is a pre-loaded result

power_plots(mul1_del_results[[1]])
# }

Run the code above in your browser using DataLab