powered by
Returns all main plots for a single deletion analysis result.
deletion_plots( del_result, opts = genie_plot_options(), variance_components_plot = FALSE, power_plots = FALSE )
Result from a call to deletion_analysis.
A list with all options needed for rgenie plotting functions.
If TRUE, then variance_components_plot() is called.
If TRUE, then power_plots() is called.
Returns a list of ggplot objects.
genie_plot_options
deletion_analysis
deletion_summary_plot
deletion_alleles_plot
deletion_profile_plot
replicate_summary_plot
replicate_qc_plot
allele_effect_plot
variance_components_plot
power_plots
# NOT RUN { # Note: First run deletion_analysis() # mul1_del_results is a pre-loaded result deletion_plots(mul1_del_results[[1]], genie_plot_options()) # }
Run the code above in your browser using DataLab