power_analysis: Performs estimates of power to detect effects of alleles at different
read fractions, given the variance observed in the del_result replicates.
Description
Performs estimates of power to detect effects of alleles at different
read fractions, given the variance observed in the del_result replicates.
# NOT RUN {# Note: First run deletion_analysis()# mul1_del_results is a pre-loaded resultpwr = power_analysis(mul1_del_results[[1]])
power_plots(mul1_del_results[[1]])
# }