power_plots: Returns a set of plots summarising the expected power to detect a significant
effect given various allele fraction and effect size combinations.
Description
Returns a set of plots summarising the expected power to detect a significant
effect given various allele fraction and effect size combinations.